@@ -1,25 +1,15 @@
 #!/bin/env python
 
-import os
 import sys
 import traceback
 import logging
-import atexit
-from qds_ops.entities.web import Web
-from qds_ops.entities.log import Log
-from qds_ops.entities.oozie_master import OozieMaster
-from qds_ops.entities.oozie_slave import OozieSlave
-from qds_ops.entities.oozie import Oozie
-from qds_ops.entities.chef import Chef
-from qds_ops.entities.rds import RDS
-from qds_ops.entities.scheduler import Scheduler
-from qds_ops.entities.default_dj import DefaultDJ
-from qds_ops.entities.experimental_dj import ExperimentalDJ
-from qds_ops.entities.redis_server import Redis
 from qds_ops.utils import argparse
 from qds_ops import __version__
 from qds_ops.tparty.knife import Knife
 
+from entities import Chef, RDS, Web, Log, OozieSlave,\
+    OozieMaster, Oozie, Scheduler, DefaultDJ, ExperimentalDJ,\
+    Redis
 
 def main():
 
@@ -40,18 +30,25 @@ def main():
     argparser.add_argument('--version', action='version', version=__version__)
     subparsers = argparser.add_subparsers()
 
+    # chef and rds are externally managed tiers not qubole managed
+    chef = Chef()
+    rds = RDS()
+    chef.configure_parsers(subparsers)
+    rds.configure_parsers(subparsers)
 
-    chef = Chef(subparsers)
-    web = Web(subparsers)
-    log = Log(subparsers)
-    master = OozieMaster(subparsers)
-    slave = OozieSlave(subparsers)
-    oozie = Oozie(subparsers)
-    rds = RDS(subparsers)
-    scheduler = Scheduler(subparsers)
-    defaultDJ = DefaultDJ(subparsers)
-    experimentalDJ = ExperimentalDJ(subparsers)
-    Redis(subparsers)
+    # qubole managed tiers
+    tiers = \
+        [Web(), Log(), OozieMaster(), OozieSlave(), Oozie(), Scheduler(), DefaultDJ(), ExperimentalDJ(), Redis()]
+
+    # configure common parsers
+    [
+        p.configure_common_parsers(subparsers) for p in tiers
+    ]
+
+    # configure tier specific parsers
+    [
+        p.configure_parsers() for p in tiers
+    ]
 
     args = argparser.parse_args()
     if args.debug:
