@@ -1,6 +1,5 @@
 import json
-from subprocess import PIPE, check_call
-import os
+from subprocess import check_call
 import random
 import socket
 import logging
@@ -11,7 +10,10 @@ import MySQLdb
 
 
 class RDS():
-    def __init__(self, subparser):
+    def __init__(self):
+        return
+
+    def configure_parsers(self, subparser):
         parser = subparser.add_parser("rds",
                                       help="Commands to monitor and control RDS Mysql servers")
         rds_subparser = parser.add_subparsers()
@@ -46,9 +48,7 @@ class RDS():
     def hostnames(self, args):
         knife = Knife()
         creds = knife.get_credentials(args.environment)
-        output = {}
-        output["primary"] = creds["host"]
-        output["read_replica"] = creds["rr_host"]
+        output = {"primary": creds["host"], "read_replica": creds["rr_host"]}
 
         print json.dumps(output, indent=4, sort_keys=True)
 
@@ -78,7 +78,7 @@ class RDS():
             counter = 1
             while not self.checkport(port) and counter < 5:
                 port = random.randrange(1, 1000) + 33000
-                counter = counter + 1
+                counter += 1
 
             if counter > 5:
                 raise RuntimeError("Could not find a free port")
@@ -114,7 +114,7 @@ class RDS():
             counter = 1
             while not RDS.checkport(port) and counter < 5:
                 port = random.randrange(1, 1000) + 33000
-                counter = counter + 1
+                counter += 1
 
             if counter > 5:
                 raise RuntimeError("Could not find a free port")
